var indexSectionsWithContent =
{
  0: "3_abcdefghijklmnopqrstuvwxy~",
  1: "abcdefhiklmnopqrstuvx",
  2: "sv",
  3: "abcdefghikmnoprstuv",
  4: "_abcdefghiklmnopqrstuvwx~",
  5: "abcdefghiklmnopqrstuvwxy",
  6: "abcdefghiklmnopstuv",
  7: "abcdefikmnoprsuv",
  8: "abcdejkmnprstuxy",
  9: "w",
  10: "_defgklmsuv",
  11: "3abcdfghimoprstuvw",
  12: "i"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "properties",
  10: "defines",
  11: "groups",
  12: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Properties",
  10: "Macros",
  11: "Modules",
  12: "Pages"
};

